@@ -17,7 +17,7 @@ str(drugSample)
 FP <- extrFP(disease_biomarker = drugSample$disease_biomarker,
              drug_target = drugSample$herb_target,
              method = "enrich",
-             geneset = "ImmGenTop150")
+             geneset = "KEGG")
 
 
 ## -----------------------------------------------------------------------------
